
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.23.14',
    'branch_nick': 'release-1.23-LTS',
    'revision_id': 'ef1751bebe63c04def1b16b2f876876cca376dbc',
    'revno': 10105
}
